import sys
from datetime import datetime, timedelta

import requests
from requests.adapters import HTTPAdapter
from requests.packages.urllib3.util.retry import Retry

retry_strategy = Retry(
    total=10,
    status_forcelist=[429, 500, 502, 503, 504],
    method_whitelist=["HEAD", "GET", "OPTIONS"]
)
adapter = HTTPAdapter(max_retries=retry_strategy)
http = requests.Session()
http.mount("https://", adapter)
http.mount("http://", adapter)

url_prefix = 'https://search.wikileaks.org/syria-files/emailid'

count = 0
present = 0
with open('results.csv', 'r') as output:
    for line in output.readlines():
        count += 1
        if ',true' in line:
            present += 1
last_completed_index = count - 1

msg = ''
rate_count = 0
time_start = datetime.now()
total = 2434900
with open('ids_to_query.txt', 'r') as input, open('results.csv', 'a') as output:
    for ix, line in enumerate(input.readlines()):
        if last_completed_index < ix:
            id = line.strip()
            count += 1
            rate_count += 1
            time_delta = datetime.now() - time_start
            rate = rate_count / time_delta.total_seconds()
            remaining = total - count
            remaining_time = timedelta(seconds=remaining / rate)
            msg = '{: >7} / found {} of {} ({:%}%, rate {:.4}/s, eta {})'.format(id,
                                                                                 present, count, present / count, rate, remaining_time)
            sys.stdout.write(100 * '\b' + msg)
            sys.stdout.flush()
            r = http.get(url_prefix + '/' + id)
            if len(r.text) == 0:
                res = 'false'
            else:
                res = 'true'
                present += 1
            output.write(id + ',' + res + '\n')
